/*
   FALCON - The Falcon Programming Language.
   FILE: fxchat_errhand.cpp

   Falcon script Xchat plugin
   Definition of xchat specific error handler.
   -------------------------------------------------------------------
   Author: Giancarlo Niccolai
   Begin: 2007-07-28 18:55:17

   -------------------------------------------------------------------
   (C) Copyright 2004: the FALCON developers (see list in AUTHORS file)

   See LICENSE file for licensing details.
*/

/** \file
   Falcon script Xchat plugin
   Definition of xchat specific error handler.
*/

#include "fxchat_errhand.h"
#include "fxchat_script.h"
#include "fxchat.h"

XChatErrHand::XChatErrHand( ScriptData *mod ):
	m_module( mod )
{}

void XChatErrHand::handleError( Falcon::Error *error )
{
	// signal the module had an error.
	if ( m_module != 0 )
   {
		m_module->m_bStatus = false;

      // also, prevent further callbacks to take place in this script.
      m_module->unhookAll();

      // the user will have to restart the module manually.
   }

	// convert the error in string.
	Falcon::String str;
   error->toString( str );

   // now prefix every row with "plugin name"
   str = (PNAME ": ") + str;

   Falcon::uint32 pos = str.find( "\n" );
   while( pos != Falcon::String::npos )
   {
   	pos++;
   	str.insert( pos, 0, PNAME ": " );
   	pos = str.find( "\n", pos );
   }

   xchat_print_falcon( str );
}

/* end of fxchat_errhand.cpp */
